# Changelog

## 0.4.0 (2025-12-04)

Full Changelog: [v0.0.1...v0.4.0](https://github.com/zavudev/sdk-python/compare/v0.0.1...v0.4.0)

### Features

* add github ([da0ecc7](https://github.com/zavudev/sdk-python/commit/da0ecc7146bd4afb80b6e20a503383055d636a32))
* fixes ([757385d](https://github.com/zavudev/sdk-python/commit/757385d5eac1135805974118f5f9d0f23f0f10e6))


### Chores

* sync repo ([2dcaa60](https://github.com/zavudev/sdk-python/commit/2dcaa608c20687cc067e10e2f0b2762e248c7fef))
* update SDK settings ([6989bfd](https://github.com/zavudev/sdk-python/commit/6989bfd96bf1ac9b3afc37b2d0decdfa8b3ebfd0))
